# debugonce

`debugonce` is a Python utility designed to help developers effortlessly capture and reproduce bugs by recording function calls and runtime context. With the `@debugonce` decorator, you can easily log input arguments, environment variables, and more, making it simpler to diagnose issues in your code.

## Key Features

- **@debugonce Decorator**: Capture input arguments, environment variables, current working directory, Python version, and stack traces upon exceptions.
- **Optional Logging**: Capture contents of accessed files and HTTP requests if opted-in.
- **Storage**: All captured data is stored in a `.debugonce/` folder as JSON, tracebacks, and logs.
- **Command-Line Interface**: A CLI tool (`debugonce-cli`) with commands to replay, export, list, and clean captured sessions.

## Installation

To install `debugonce`, you can clone the repository and install the package using pip:

```bash
git clone https://github.com/Sujith-sunny/debugonce.git
cd debugonce
pip install .
```

## Usage

To use the `@debugonce` decorator, simply apply it to your function:

```python
from debugonce import debugonce

@debugonce
def my_function(arg1, arg2):
    # Your function logic here
```

When an exception occurs, the state will be captured automatically.

## CLI Guide

The `debugonce-cli` provides several commands:

- **replay**: Rerun the captured function with stored input.
  
  ```bash
  debugonce-cli replay session.json
  ```

- **export**: Generate a standalone bug reproduction script.
  
  ```bash
  debugonce-cli export <session_id>
  ```

- **list**: Show all captured sessions.
  
  ```bash
  debugonce-cli list
  ```

- **clean**: Clear stored sessions.
  
  ```bash
  debugonce-cli clean
  ```

## Example Outputs

After running a function decorated with `@debugonce`, you will find the captured data in the `.debugonce/` folder. This includes:

- `session_<timestamp>.json`: Contains input arguments and environment details.
- `traceback_<timestamp>.log`: Logs the stack trace if an exception occurred.

## Contributing

Contributions are welcome! Please feel free to submit a pull request or open an issue for any enhancements or bug fixes.

## License

This project is licensed under the MIT License. See the LICENSE file for more details.